/*
 * Copyright (C) 2014-2024 Philip Helger (www.helger.com)
 * philip[at]helger[dot]com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.helger.photon.io;

import static org.junit.Assert.assertTrue;

import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.TestRule;

import com.helger.commons.collection.impl.CommonsHashSet;
import com.helger.commons.collection.impl.ICommonsSet;
import com.helger.commons.id.factory.ILongIDFactory;
import com.helger.photon.io.mock.PhotonIOTestRule;

/**
 * Test class for class {@link WebIOLongIDFactory}.
 *
 * @author Philip Helger
 */
public final class WebIOLongIDFactoryTest
{
  @Rule
  public final TestRule m_aRule = new PhotonIOTestRule ();

  @Test
  public void testFileBasedIDProvider ()
  {
    final ILongIDFactory aIDProvider = new WebIOLongIDFactory ("junit.ids.long.dat");
    final ICommonsSet <Long> aIDs = new CommonsHashSet <> ();

    for (int i = 0; i < 1000; ++i)
    {
      final long nID = aIDProvider.getNewID ();
      assertTrue ("Failed to add ID " + nID, aIDs.add (Long.valueOf (nID)));
    }
  }
}
