/*
 * Copyright (C) 2014-2024 Philip Helger (www.helger.com)
 * philip[at]helger[dot]com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.helger.photon.uicore.page;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Logging implementation of {@link ICSRFErrorHandler}
 *
 * @author Philip Helger
 */
public class LoggingCSRFErrorHandler implements ICSRFErrorHandler
{
  private static final Logger LOGGER = LoggerFactory.getLogger (LoggingCSRFErrorHandler.class);

  public void onCSRFError (@Nonnull final IWebPageExecutionContext aWPEC,
                           @Nullable final String sProvidedNonce,
                           @Nonnull final String sExpectedNone)
  {
    LOGGER.error ("The expected CSRF nonce on page '" +
                  aWPEC.getWebPage ().getID () +
                  "' was not present or modified.\nExpected: '" +
                  sExpectedNone +
                  "'\nBut got: '" +
                  sProvidedNonce +
                  "'");
  }
}
